@@ -7,10 +7,11 @@
 import time
 
 from blockchain.candidate_block.get_candidate_blocks import GetCandidateBlocks
-from lib.mixlib import dprint
-from node.myownp2pn import mynode
-from node.unl import get_as_node_type
-from node.unl import get_unl_nodes
+from lib.log import get_logger
+from node.node import Node
+from node.unl import Unl
+
+logger = get_logger("CONSENSUS_SECOND_ROUND")
 
 
 def consensus_round_2(block):
@@ -25,29 +26,30 @@ def consensus_round_2(block):
       round 2 to be done
     """
 
-    unl_nodes = get_unl_nodes()
-    if not block.raund_2_node:
-        dprint("Raund 2: in get candidate block hashes\n")
+    logger.info(
+        "BLOCK#{block.sequance_number}:{block.empty_block_number} Second round is starting"
+    )
 
-        mynode.main_node.send_my_block_hash(get_as_node_type(unl_nodes))
+    unl_nodes = Unl.get_unl_nodes()
+    if not block.raund_2_node:
+
+        Node.main_node.send_my_block_hash(Unl.get_as_node_type(unl_nodes))
         block.raund_2_node = True
         block.save_block()
 
     candidate_class = GetCandidateBlocks()
-    dprint("Raund 2 Conditions")
-    dprint(
-        len(candidate_class.candidate_block_hashes) > (
-            (len(unl_nodes) * 80) / 100))
-    dprint(
-        (int(time.time()) - block.raund_2_starting_time) < block.raund_2_time)
 
     if len(candidate_class.candidate_block_hashes) > (
         (len(unl_nodes) * 80) / 100):
+        logger.info("Enough candidate block hashes received")
 
         if not (int(time.time()) -
                 block.raund_2_starting_time) < block.raund_2_time:
-            dprint("Raund 2: first ok")
+            logger.info("True time")
+
             for candidate_block in candidate_class.candidate_block_hashes[:]:
+                logger.debug(f"Candidate block hash {candidate_block}")
+
                 tx_valid = 0
 
                 if block.hash == candidate_block["hash"]:
@@ -59,25 +61,29 @@ def consensus_round_2(block):
                         if candidate_block["hash"] == other_block["hash"]:
                             tx_valid += 1
 
+                logger.debug(f"Hash valid of  {candidate_block} : {tx_valid}")
                 if tx_valid > ((len(unl_nodes) * 80) / 100):
 
-                    dprint("Raund 2: second ok")
                     if block.hash == candidate_block["hash"]:
+                        logger.info("Block approved")
                         block.validated = True
                         block.validated_time = int(time.time())
                         block.raund_2 = True
 
                     else:
-                        print("Raund 2: my block is not valid")
-                        node = mynode.main_node
-                        unl_list = get_as_node_type(
-                            [candidate_block["sender"]])
+                        sender = candidate_block["sender"]
+                        logger.warning(
+                            f"Our block is not valid, the system will try to get true block from node {sender}"
+                        )
+                        node = Node.main_node
+                        unl_list = Unl.get_as_node_type([sender])
                         node.send_data_to_node(unl_list[0], "sendmefullblock")
-                        block.dowload_true_block = candidate_block["sender"]
+                        block.dowload_true_block = sender
                     block.save_block()
 
         else:
             if not block.decrease_the_time_2 == 3:
+                logger.info("Decrease the time")
                 block.decrease_the_time_2 += 1
                 block.increase_the_time_2 = 0
                 block.save_block()
@@ -86,6 +92,9 @@ def consensus_round_2(block):
         if not (int(time.time()) -
                 block.raund_2_starting_time) < block.raund_2_time:
             if not block.increase_the_time_2 == 3:
+                logger.info("Increase the time")
                 block.increase_the_time_2 += 1
                 block.decrease_the_time_2 = 0
                 block.save_block()
+
+    logger.info("Second round is done")
