@@ -6,10 +6,14 @@
 # file, You can obtain one at https://mozilla.org/MPL/2.0/.
 
 
-from transactions.save_to_my_transaction import GetMyTransaction
+from transactions.get_my_transaction import GetMyTransaction
 
 
 def PrintTransactions():
+    """
+    Prints all transactions in my transaction.
+    """
+
     print("\n")
     print(*[i.__dict__ for i in GetMyTransaction()], sep = "\n\n")
     print("\n")
